@@ -21,11 +21,13 @@ __PACKAGE__->mk_accessors(
         meta perlname author
         version rules docs examples copyright
         control
+        dist_ini
     )
 );
 
 use Array::Unique;
 use Carp qw(confess);
+use Config::INI::Reader ();
 use CPAN ();
 use CPAN::Meta;
 use Cwd qw( getcwd );
@@ -36,6 +38,7 @@ use DhMakePerl::PodParser ();
 use File::Basename qw(basename dirname);
 use File::Find qw(find);
 use File::Path ();
+use File::Which;
 use File::Spec::Functions qw(catfile catpath splitpath);
 use Parse::DebianChangelog;
 use Text::Balanced qw(extract_quotelike);
@@ -194,6 +197,10 @@ sub process_meta {
 
     $meta = CPAN::Meta->load_file($meta);
     $self->meta( $meta->as_struct );
+
+    my $dist_ini_fn = $self->main_file('dist.ini');
+    $self->dist_ini( Config::INI::Reader->read_file($dist_ini_fn) )
+        if -e $dist_ini_fn;
 }
 
 sub set_package_name {
@@ -974,9 +981,16 @@ sub create_copyright {
     # information for anything besides general information.
     push @res, 'Files: *';
 
+    my $cprt_year;
+    if (    $self->dist_ini
+        and $self->dist_ini->{_}{copyright_year} )
+    {
+        $cprt_year = $self->dist_ini->{_}{copyright_year};
+    }
     # Absence of author should have already been reported in the
     # Header section
-    push @res, "Copyright: $cprt_author";
+    push @res,
+        "Copyright: " . ( $cprt_year ? "$cprt_year, " : '' ) . $cprt_author;
 
     # This is far from foolproof, but usually works with most
     # boilerplate-generated modules.
@@ -1387,6 +1401,14 @@ sub discover_dependencies {
             }
         );
     }
+    elsif (which('apt-file')) {
+        warn "No APT contents can be loaded but apt-file seems installed.\n";
+        warn "Please run 'apt-file update' as root.\n";
+        warn "(If that doesn't help, please report a bug against dh-make-perl.)\n";
+        warn "Dependencies not updated.\n";
+
+        return ();
+    }
     else {
         warn "No APT contents can be loaded.\n";
         warn "Please install 'apt-file' package (at least version 2.5.0) and\n";
