@@ -349,12 +349,19 @@ sub setup_dir {
         $new_maindir = $orig_pwd . "/" . $dist->base_id;
 
         # rename existing directory
+        my $new_inc;
+        my $rename_to = "$new_maindir.$$";
+        while (-d $rename_to)
+        {
+            $new_inc++;
+            $rename_to = "$new_maindir.$$-$new_inc";
+        }
         if ( -d $new_maindir
-            && rename $new_maindir, "$new_maindir.$$" )
+            && rename $new_maindir, $rename_to)
         {
             print '=' x 70, "\n";
             print
-                "Unpacked tarball already existed, directory renamed to $new_maindir.$$\n";
+                "Unpacked tarball already existed, directory renamed to $rename_to\n";
             print '=' x 70, "\n";
         }
         system( "mv", $self->main_dir, "$new_maindir" ) == 0
@@ -431,8 +438,11 @@ sub install_package {
     $debname = sprintf( "%s_%s-1_%s.deb", $self->pkgname, $self->version,
         $archspec );
 
-    my $deb = $self->main_dir . "/$debname";
-    system("dpkg -i $deb") == 0
+    my $deb = $self->main_dir . "/../$debname";
+    my $dpkg_cmd = "dpkg -i $deb";
+    $dpkg_cmd = "sudo $dpkg_cmd" if $>;
+    $self->info("Running '$dpkg_cmd'...");
+    system($dpkg_cmd) == 0
         || die "Cannot install package $deb\n";
 }
 
@@ -713,11 +723,21 @@ EOF
     return $found ? 1 : 0;
 }
 
+sub reset_git_environment {
+    # The Git environment variables may be set from previous iterations
+    # of this program being run. In this case, it's possible that the
+    # Git module will use these to point to the wrong source tree.
+    delete $ENV{'GIT_DIR'};
+    delete $ENV{'GIT_WORK_TREE'};
+}
+
 sub git_import_upstream__init_debian {
     my ( $self ) = @_;
 
     require Git;
 
+    $self->reset_git_environment();
+
     Git::command( 'init', $self->main_dir );
 
     my $git = Git->repository( $self->main_dir );
@@ -748,6 +768,8 @@ sub git_add_debian {
     require Git;
     require File::Which;
 
+    $self->reset_git_environment;
+
     my $git = Git->repository( $self->main_dir );
     $git->command( 'add', 'debian' );
     $git->command( 'commit', '-m',
@@ -794,6 +816,23 @@ sub warning {
     warn "W: ", @_, "\n";
 }
 
+=item info I<string> ...
+
+In verbose mode, prints supplied arguments on STDERR, prepended with C<I: > and
+suffixed with a new line.
+
+Does nothing in non-verbose mode.
+
+=cut
+
+sub info {
+    my $self = shift;
+
+    return unless $self->cfg->verbose;
+
+    warn "I: ", @_, "\n";
+}
+
 =back
 
 =head1 AUTHOR
@@ -843,7 +882,7 @@ L<http://bugs.debian.org/dh-make-perl>
 
 =item Copyright (C) 2007-2014 Gregor Herrmann <gregoa@debian.org>
 
-=item Copyright (C) 2007,2008,2009,2010,2011,2012 Damyan Ivanov <dmn@debian.org>
+=item Copyright (C) 2007,2008,2009,2010,2011,2012,2015 Damyan Ivanov <dmn@debian.org>
 
 =item Copyright (C) 2008, Roberto C. Sanchez <roberto@connexer.com>
 
